/*
 *  This file is part of the XForms library package.
 *
 *  XForms is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as
 *  published by the Free Software Foundation; either version 2.1, or
 *  (at your option) any later version.
 *
 *  XForms is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with XForms.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef PLIGHTBUT_H
#define PLIGHTBUT_H


#define FLI_LIGHTBUTTON_BOXTYPE      FL_UP_BOX
#define FLI_LIGHTBUTTON_COL1         FL_COL1
#define FLI_LIGHTBUTTON_COL2         FL_YELLOW
#define FLI_LIGHTBUTTON_LCOL         FL_LCOL
#define FLI_LIGHTBUTTON_ALIGN        ( FL_ALIGN_CENTER | FL_ALIGN_INSIDE )
#define FLI_LIGHTBUTTON_TOPCOL       FL_COL1
#define FLI_LIGHTBUTTON_MCOL         FL_MCOL
#define FLI_LIGHTBUTTON_MINSIZE      ( ( FL_COORD ) 12 )


#endif /* PLIGHTBUT_H */


/*
 * Local variables:
 * tab-width: 4
 * indent-tabs-mode: nil
 * End:
 */
